@@ -6,6 +6,10 @@ def main():
     local_variable = None
     raise NotImplementedError()
 
+@pretty_traceback_and_exit_decorator
+def system_exit():
+    raise SystemExit(3)
+
 class RaisingRepr(object):
     def __repr__(self):
         raise Exception()
@@ -20,6 +24,12 @@ class TestCase(unittest.TestCase):
         with self.assertRaises(SystemExit):
             main()
 
+    def test_system_exit(self):
+        try:
+            system_exit()
+        except SystemExit, error:
+           self.assertEquals(error.args, (3, ))
+
 if __name__ == "__main__":
     main()
     
